#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.fish"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[2273]; const double alignment; void * const ptr;}  fish_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0010, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0004, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0010, 0000, 0000, 0000, 
  0000, 0113, 0055, 0223, 0002, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 
  0010, 0001, 0000, 0000, 0014, 0001, 0000, 0000, 0371, 0011, 0330, 0305, 0007, 0000, 0000, 0000, 
  0014, 0001, 0000, 0000, 0015, 0000, 0166, 0000, 0040, 0001, 0000, 0000, 0204, 0001, 0000, 0000, 
  0201, 0321, 0040, 0031, 0003, 0000, 0000, 0000, 0204, 0001, 0000, 0000, 0005, 0000, 0114, 0000, 
  0214, 0001, 0000, 0000, 0220, 0001, 0000, 0000, 0113, 0120, 0220, 0013, 0004, 0000, 0000, 0000, 
  0220, 0001, 0000, 0000, 0004, 0000, 0114, 0000, 0224, 0001, 0000, 0000, 0230, 0001, 0000, 0000, 
  0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 0230, 0001, 0000, 0000, 0001, 0000, 0114, 0000, 
  0234, 0001, 0000, 0000, 0240, 0001, 0000, 0000, 0204, 0223, 0352, 0035, 0007, 0000, 0000, 0000, 
  0240, 0001, 0000, 0000, 0007, 0000, 0166, 0000, 0250, 0001, 0000, 0000, 0305, 0010, 0000, 0000, 
  0265, 0144, 0045, 0040, 0000, 0000, 0000, 0000, 0305, 0010, 0000, 0000, 0007, 0000, 0114, 0000, 
  0314, 0010, 0000, 0000, 0320, 0010, 0000, 0000, 0316, 0353, 0312, 0360, 0006, 0000, 0000, 0000, 
  0320, 0010, 0000, 0000, 0005, 0000, 0114, 0000, 0330, 0010, 0000, 0000, 0340, 0010, 0000, 0000, 
  0160, 0141, 0156, 0145, 0154, 0057, 0000, 0000, 0006, 0000, 0000, 0000, 0146, 0151, 0163, 0150, 
  0055, 0155, 0145, 0156, 0165, 0056, 0170, 0155, 0154, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0255, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 
  0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 0265, 0125, 0162, 0313, 0054, 0316, 0120, 0010, 
  0050, 0112, 0115, 0113, 0055, 0112, 0315, 0113, 0116, 0055, 0126, 0360, 0004, 0312, 0051, 0051, 
  0044, 0046, 0227, 0144, 0346, 0347, 0101, 0244, 0221, 0144, 0225, 0364, 0355, 0270, 0154, 0260, 
  0231, 0340, 0221, 0232, 0123, 0200, 0105, 0053, 0110, 0030, 0247, 0036, 0307, 0244, 0374, 0322, 
  0022, 0054, 0232, 0300, 0342, 0040, 0135, 0134, 0000, 0226, 0352, 0073, 0010, 0000, 0050, 0165, 
  0165, 0141, 0171, 0051, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0157, 0162, 0147, 0057, 0002, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0146, 0151, 0163, 0150, 0056, 0165, 0151, 0000, 0350, 0152, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0355, 0135, 0337, 0163, 0243, 0066, 0020, 0176, 0357, 0137, 0241, 0362, 0332, 0161, 
  0154, 0310, 0345, 0222, 0273, 0261, 0175, 0163, 0115, 0173, 0327, 0316, 0164, 0072, 0067, 0275, 
  0353, 0063, 0043, 0303, 0332, 0350, 0042, 0044, 0052, 0204, 0235, 0374, 0367, 0025, 0340, 0044, 
  0070, 0306, 0200, 0020, 0076, 0377, 0010, 0231, 0074, 0044, 0106, 0273, 0150, 0077, 0264, 0273, 
  0037, 0273, 0040, 0217, 0077, 0334, 0207, 0024, 0055, 0101, 0304, 0204, 0263, 0211, 0145, 0137, 
  0214, 0054, 0004, 0314, 0343, 0076, 0141, 0213, 0211, 0365, 0357, 0267, 0117, 0203, 0033, 0353, 
  0303, 0364, 0247, 0361, 0317, 0203, 0001, 0372, 0014, 0014, 0004, 0226, 0340, 0243, 0025, 0221, 
  0001, 0132, 0120, 0354, 0003, 0272, 0274, 0160, 0234, 0213, 0021, 0032, 0014, 0324, 0040, 0302, 
  0044, 0210, 0071, 0366, 0140, 0372, 0023, 0102, 0143, 0001, 0377, 0045, 0104, 0100, 0214, 0050, 
  0231, 0115, 0254, 0205, 0274, 0373, 0305, 0172, 0076, 0121, 0052, 0146, 0015, 0263, 0161, 0174, 
  0366, 0035, 0074, 0211, 0074, 0212, 0343, 0170, 0142, 0175, 0226, 0167, 0037, 0375, 0357, 0111, 
  0054, 0103, 0140, 0322, 0102, 0304, 0237, 0130, 0370, 0351, 0177, 0333, 0112, 0045, 0224, 0114, 
  0044, 0170, 0004, 0102, 0076, 0040, 0206, 0103, 0230, 0130, 0224, 0257, 0100, 0130, 0123, 0173, 
  0074, 0174, 0074, 0120, 0076, 0056, 0211, 0242, 0164, 0234, 0163, 0165, 0125, 0067, 0162, 0211, 
  0151, 0002, 0326, 0364, 0262, 0156, 0134, 0054, 0041, 0162, 0011, 0363, 0004, 0144, 0363, 0255, 
  0237, 0102, 0204, 0027, 0120, 0024, 0170, 0061, 0223, 0361, 0060, 0207, 0103, 0027, 0031, 0247, 
  0032, 0231, 0321, 0205, 0075, 0332, 0374, 0151, 0212, 0225, 0075, 0152, 0010, 0225, 0255, 0013, 
  0125, 0213, 0071, 0275, 0004, 0317, 0326, 0001, 0357, 0317, 0120, 0111, 0347, 0270, 0221, 0364, 
  0317, 0135, 0213, 0151, 0111, 0142, 0062, 0243, 0312, 0242, 0157, 0042, 0201, 0272, 0031, 0171, 
  0230, 0271, 0163, 0356, 0045, 0261, 0065, 0375, 0204, 0151, 0134, 0073, 0236, 0170, 0234, 0271, 
  0351, 0237, 0326, 0064, 0000, 0032, 0015, 0146, 0202, 0257, 0142, 0020, 0046, 0166, 0070, 0007, 
  0266, 0143, 0105, 0230, 0317, 0127, 0003, 0217, 0362, 0227, 0142, 0325, 0166, 0374, 0106, 0060, 
  0345, 0213, 0334, 0220, 0071, 0211, 0003, 0067, 0022, 0060, 0007, 0241, 0242, 0017, 0304, 0256, 
  0237, 0037, 0354, 0146, 0262, 0063, 0056, 0174, 0020, 0356, 0212, 0370, 0062, 0330, 0362, 0270, 
  0355, 0341, 0222, 0110, 0005, 0033, 0222, 0002, 0263, 0230, 0142, 0211, 0025, 0210, 0023, 0353, 
  0001, 0322, 0263, 0251, 0151, 0242, 0057, 0317, 0323, 0254, 0325, 0364, 0020, 0201, 0033, 0220, 
  0164, 0251, 0346, 0006, 0155, 0011, 0170, 0001, 0241, 0076, 0312, 0002, 0047, 0303, 0164, 0220, 
  0375, 0253, 0056, 0335, 0214, 0337, 0257, 0155, 0057, 0103, 0356, 0127, 0165, 0064, 0203, 0055, 
  0127, 0072, 0110, 0207, 0073, 0117, 0343, 0065, 0127, 0102, 0033, 0200, 0313, 0144, 0270, 0040, 
  0312, 0047, 0261, 0124, 0341, 0335, 0232, 0252, 0070, 0057, 0211, 0207, 0151, 0023, 0301, 0070, 
  0302, 0236, 0312, 0066, 0052, 0054, 0227, 0216, 0056, 0107, 0010, 0173, 0351, 0211, 0134, 0054, 
  0000, 0027, 0014, 0057, 0005, 0053, 0221, 0222, 0263, 0227, 0220, 0025, 0344, 0235, 0015, 0005, 
  0055, 0320, 0153, 0213, 0340, 0263, 0171, 0233, 0237, 0355, 0266, 0042, 0067, 0041, 0015, 0034, 
  0356, 0054, 0377, 0340, 0245, 0144, 0111, 0006, 0300, 0063, 0240, 0245, 0253, 0331, 0375, 0103, 
  0051, 0332, 0065, 0261, 0326, 0110, 0324, 0240, 0321, 0106, 0324, 0207, 0071, 0116, 0250, 0324, 
  0027, 0026, 0340, 0001, 0131, 0246, 0341, 0344, 0121, 0103, 0345, 0305, 0050, 0015, 0164, 0131, 
  0264, 0235, 0346, 0031, 0103, 0107, 0060, 0211, 0301, 0115, 0230, 0212, 0073, 0224, 0260, 0132, 
  0310, 0212, 0221, 0162, 0123, 0051, 0366, 0356, 0224, 0163, 0324, 0237, 0016, 0356, 0043, 0314, 
  0374, 0026, 0006, 0316, 0011, 0245, 0055, 0304, 0042, 0036, 0223, 0334, 0327, 0107, 0125, 0146, 
  0225, 0316, 0177, 0074, 0054, 0131, 0365, 0155, 0074, 0301, 0347, 0014, 0072, 0361, 0204, 0333, 
  0355, 0344, 0165, 0146, 0256, 0020, 0340, 0370, 0150, 0374, 0310, 0351, 0375, 0250, 0304, 0217, 
  0354, 0056, 0374, 0250, 0014, 0200, 0162, 0343, 0133, 0031, 0336, 0302, 0350, 0155, 0016, 0357, 
  0335, 0271, 0051, 0061, 0262, 0246, 0300, 0374, 0306, 0122, 0165, 0341, 0246, 0004, 0242, 0055, 
  0170, 0266, 0103, 0114, 0005, 0267, 0112, 0111, 0325, 0325, 0101, 0251, 0201, 0036, 0213, 0065, 
  0346, 0145, 0225, 0334, 0314, 0276, 0061, 0146, 0060, 0105, 0140, 0337, 0132, 0077, 0046, 0304, 
  0152, 0273, 0243, 0026, 0132, 0225, 0210, 0275, 0255, 0224, 0052, 0005, 0255, 0034, 0270, 0277, 
  0362, 0264, 0225, 0102, 0227, 0145, 0060, 0373, 0322, 0052, 0023, 0064, 0000, 0320, 0024, 0104, 
  0275, 0144, 0233, 0227, 0221, 0250, 0256, 0302, 0173, 0114, 0311, 0242, 0232, 0156, 0254, 0005, 
  0261, 0224, 0202, 0050, 0126, 0000, 0161, 0371, 0200, 0342, 0220, 0265, 0362, 0025, 0220, 0105, 
  0040, 0055, 0224, 0325, 0062, 0122, 0127, 0243, 0176, 0136, 0235, 0052, 0221, 0035, 0126, 0353, 
  0337, 0225, 0202, 0252, 0323, 0220, 0121, 0052, 0062, 0110, 0107, 0255, 0251, 0135, 0105, 0132, 
  0332, 0111, 0361, 0164, 0127, 0376, 0123, 0310, 0010, 0166, 0204, 0214, 0303, 0257, 0372, 0235, 
  0326, 0064, 0364, 0345, 0135, 0126, 0031, 0133, 0326, 0205, 0165, 0273, 0375, 0172, 0272, 0276, 
  0374, 0065, 0342, 0125, 0276, 0120, 0357, 0017, 0306, 0076, 0141, 0350, 0027, 0106, 0276, 0121, 
  0343, 0037, 0225, 0076, 0322, 0146, 0145, 0155, 0244, 0327, 0353, 0123, 0133, 0125, 0332, 0151, 
  0327, 0054, 0375, 0066, 0003, 0271, 0101, 0120, 0262, 0255, 0052, 0341, 0016, 0300, 0356, 0012, 
  0360, 0152, 0162, 0347, 0064, 0126, 0121, 0013, 0130, 0155, 0334, 0113, 0317, 0355, 0256, 0243, 
  0110, 0215, 0236, 0216, 0360, 0353, 0022, 0103, 0315, 0272, 0302, 0337, 0152, 0000, 0342, 0163, 
  0224, 0326, 0267, 0337, 0233, 0234, 0043, 0275, 0013, 0016, 0261, 0270, 0113, 0042, 0163, 0333, 
  0265, 0356, 0250, 0353, 0325, 0205, 0014, 0102, 0316, 0210, 0227, 0336, 0231, 0054, 0100, 0132, 
  0323, 0354, 0012, 0053, 0167, 0026, 0017, 0046, 0152, 0033, 0363, 0275, 0346, 0351, 0246, 0171, 
  0332, 0351, 0054, 0375, 0164, 0224, 0206, 0072, 0111, 0107, 0015, 0323, 0122, 0243, 0364, 0144, 
  0032, 0020, 0176, 0117, 0227, 0107, 0041, 0040, 0144, 0313, 0345, 0110, 0002, 0202, 0251, 0252, 
  0264, 0267, 0260, 0304, 0022, 0064, 0012, 0156, 0207, 0132, 0307, 0246, 0246, 0346, 0313, 0330, 
  0124, 0113, 0243, 0032, 0330, 0376, 0126, 0161, 0023, 0270, 0233, 0101, 0335, 0111, 0270, 0060, 
  0307, 0330, 0070, 0112, 0064, 0300, 0266, 0026, 0127, 0143, 0156, 0165, 0331, 0163, 0053, 0135, 
  0156, 0345, 0361, 0060, 0124, 0013, 0356, 0265, 0320, 0253, 0133, 0356, 0146, 0366, 0042, 0311, 
  0221, 0110, 0030, 0132, 0005, 0300, 0024, 0060, 0304, 0273, 0003, 0377, 0375, 0061, 0063, 0244, 
  0307, 0353, 0324, 0223, 0244, 0236, 0044, 0065, 0043, 0111, 0033, 0053, 0246, 0347, 0111, 0075, 
  0117, 0352, 0171, 0322, 0076, 0171, 0222, 0375, 0243, 0170, 0322, 0321, 0126, 0110, 0333, 0126, 
  0003, 0265, 0060, 0154, 0137, 0040, 0075, 0252, 0056, 0113, 0233, 0116, 0103, 0143, 0234, 0364, 
  0233, 0054, 0007, 0177, 0010, 0102, 0267, 0141, 0173, 0270, 0147, 0211, 0212, 0105, 0363, 0233, 
  0276, 0047, 0335, 0276, 0047, 0355, 0234, 0166, 0117, 0372, 0043, 0043, 0141, 0006, 0160, 0337, 
  0225, 0356, 0273, 0322, 0072, 0105, 0212, 0353, 0263, 0354, 0112, 0137, 0237, 0146, 0127, 0272, 
  0314, 0263, 0373, 0106, 0365, 0061, 0067, 0252, 0337, 0365, 0215, 0352, 0275, 0065, 0252, 0013, 
  0357, 0011, 0105, 0002, 0226, 0004, 0126, 0356, 0372, 0041, 0334, 0123, 0051, 0253, 0236, 0304, 
  0015, 0247, 0221, 0212, 0323, 0254, 0314, 0073, 0175, 0145, 0136, 0067, 0257, 0146, 0236, 0367, 
  0152, 0036, 0173, 0370, 0104, 0050, 0034, 0123, 0001, 0276, 0105, 0231, 0174, 0133, 0311, 0303, 
  0243, 0222, 0213, 0267, 0371, 0353, 0252, 0316, 0345, 0315, 0033, 0373, 0346, 0352, 0372, 0235, 
  0335, 0127, 0337, 0317, 0260, 0372, 0236, 0056, 0342, 0333, 0200, 0363, 0030, 0104, 0361, 0235, 
  0243, 0334, 0223, 0275, 0374, 0300, 0271, 0370, 0362, 0356, 0127, 0136, 0277, 0002, 0115, 0141, 
  0301, 0114, 0375, 0066, 0274, 0107, 0356, 0013, 0364, 0175, 0201, 0176, 0357, 0174, 0311, 0076, 
  0041, 0276, 0164, 0323, 0363, 0045, 0375, 0133, 0103, 0173, 0164, 0056, 0301, 0265, 0365, 0075, 
  0143, 0067, 0367, 0216, 0273, 0264, 0004, 0074, 0344, 0013, 0140, 0300, 0133, 0365, 0162, 0033, 
  0135, 0342, 0132, 0132, 0074, 0027, 0152, 0052, 0161, 0143, 0136, 0334, 0351, 0045, 0357, 0372, 
  0262, 0153, 0162, 0344, 0157, 0134, 0142, 0212, 0162, 0000, 0020, 0051, 0244, 0327, 0367, 0246, 
  0047, 0065, 0044, 0317, 0215, 0236, 0140, 0131, 0137, 0270, 0070, 0042, 0314, 0124, 0167, 0053, 
  0162, 0336, 0234, 0133, 0350, 0361, 0213, 0116, 0031, 0165, 0207, 0254, 0272, 0063, 0146, 0255, 
  0301, 0070, 0032, 0063, 0354, 0016, 0003, 0102, 0034, 0001, 0370, 0257, 0062, 0036, 0174, 0301, 
  0312, 0157, 0221, 0032, 0234, 0307, 0204, 0223, 0210, 0002, 0371, 0325, 0352, 0203, 0300, 0121, 
  0004, 0001, 0373, 0320, 0101, 0240, 0257, 0155, 0234, 0114, 0155, 0343, 0263, 0040, 0176, 0036, 
  0160, 0263, 0030, 0344, 0234, 0013, 0325, 0026, 0174, 0345, 0166, 0303, 0216, 0075, 0116, 0223, 
  0220, 0265, 0125, 0326, 0051, 0073, 0126, 0253, 0114, 0236, 0157, 0112, 0134, 0256, 0043, 0277, 
  0007, 0351, 0026, 0137, 0373, 0113, 0260, 0071, 0230, 0147, 0237, 0247, 0050, 0314, 0245, 0213, 
  0245, 0304, 0136, 0240, 0235, 0022, 0112, 0352, 0202, 0074, 0172, 0122, 0166, 0156, 0044, 0263, 
  0167, 0253, 0056, 0334, 0052, 0006, 0217, 0063, 0377, 0120, 0176, 0125, 0321, 0245, 0171, 0175, 
  0016, 0152, 0237, 0266, 0203, 0176, 0125, 0267, 0021, 0305, 0106, 0313, 0363, 0315, 0305, 0221, 
  0371, 0147, 0027, 0352, 0236, 0167, 0356, 0265, 0246, 0205, 0135, 0174, 0215, 0147, 0111, 0111, 
  0070, 0163, 0323, 0115, 0232, 0213, 0373, 0353, 0332, 0157, 0336, 0231, 0052, 0366, 0311, 0202, 
  0310, 0270, 0203, 0005, 0313, 0222, 0020, 0004, 0361, 0332, 0240, 0170, 0040, 0037, 0035, 0365, 
  0076, 0272, 0323, 0107, 0013, 0145, 0300, 0127, 0343, 0244, 0166, 0227, 0116, 0332, 0373, 0323, 
  0211, 0223, 0322, 0276, 0305, 0335, 0267, 0270, 0367, 0324, 0342, 0166, 0216, 0273, 0305, 0175, 
  0033, 0200, 0267, 0261, 0033, 0257, 0340, 0122, 0305, 0064, 0127, 0362, 0305, 0202, 0352, 0076, 
  0145, 0132, 0121, 0030, 0377, 0047, 0123, 0213, 0070, 0103, 0217, 0275, 0123, 0244, 0256, 0024, 
  0320, 0270, 0055, 0302, 0135, 0267, 0327, 0115, 0324, 0264, 0330, 0131, 0167, 0117, 0105, 0377, 
  0055, 0306, 0047, 0360, 0312, 0045, 0314, 0127, 0200, 0113, 0056, 0164, 0164, 0275, 0046, 0037, 
  0275, 0074, 0375, 0027, 0105, 0333, 0076, 0116, 0337, 0277, 0047, 0332, 0277, 0047, 0172, 0250, 
  0367, 0104, 0117, 0167, 0257, 0154, 0235, 0235, 0242, 0153, 0355, 0255, 0337, 0364, 0172, 0323, 
  0306, 0215, 0203, 0343, 0374, 0073, 0060, 0006, 0171, 0063, 0367, 0351, 0255, 0301, 0315, 0217, 
  0221, 0200, 0070, 0342, 0054, 0126, 0263, 0031, 0330, 0166, 0376, 0245, 0065, 0353, 0035, 0367, 
  0307, 0303, 0215, 0221, 0365, 0362, 0127, 0326, 0264, 0260, 0141, 0177, 0251, 0370, 0213, 0017, 
  0343, 0342, 0267, 0244, 0074, 0235, 0040, 0242, 0330, 0203, 0200, 0123, 0225, 0346, 0206, 0133, 
  0166, 0075, 0033, 0074, 0036, 0026, 0276, 0217, 0352, 0177, 0316, 0066, 0145, 0211, 0000, 0050, 
  0165, 0165, 0141, 0171, 0051, 0141, 0160, 0160, 0154, 0145, 0164, 0057, 0007, 0000, 0000, 0000, 
  0146, 0151, 0163, 0150, 0057, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0005, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[2273]; const double alignment; void * const ptr;}  fish_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\000\001\000\000\000\000\000\050\010\000\000\000"
  "\000\000\000\000\001\000\000\000\003\000\000\000\003\000\000\000"
  "\004\000\000\000\006\000\000\000\007\000\000\000\010\000\000\000"
  "\000\113\055\223\002\000\000\000\000\001\000\000\006\000\114\000"
  "\010\001\000\000\014\001\000\000\371\011\330\305\007\000\000\000"
  "\014\001\000\000\015\000\166\000\040\001\000\000\204\001\000\000"
  "\201\321\040\031\003\000\000\000\204\001\000\000\005\000\114\000"
  "\214\001\000\000\220\001\000\000\113\120\220\013\004\000\000\000"
  "\220\001\000\000\004\000\114\000\224\001\000\000\230\001\000\000"
  "\324\265\002\000\377\377\377\377\230\001\000\000\001\000\114\000"
  "\234\001\000\000\240\001\000\000\204\223\352\035\007\000\000\000"
  "\240\001\000\000\007\000\166\000\250\001\000\000\305\010\000\000"
  "\265\144\045\040\000\000\000\000\305\010\000\000\007\000\114\000"
  "\314\010\000\000\320\010\000\000\316\353\312\360\006\000\000\000"
  "\320\010\000\000\005\000\114\000\330\010\000\000\340\010\000\000"
  "\160\141\156\145\154\057\000\000\006\000\000\000\146\151\163\150"
  "\055\155\145\156\165\056\170\155\154\000\000\000\000\000\000\000"
  "\255\000\000\000\001\000\000\000\170\332\263\311\115\315\053\315"
  "\054\111\315\125\310\113\314\115\265\125\162\313\054\316\120\010"
  "\050\112\115\113\055\112\315\113\116\055\126\360\004\312\051\051"
  "\044\046\227\144\346\347\101\244\221\144\225\364\355\270\154\260"
  "\231\340\221\232\123\200\105\053\110\030\247\036\307\244\374\322"
  "\022\054\232\300\342\040\135\134\000\226\352\073\010\000\050\165"
  "\165\141\171\051\155\141\164\145\057\000\000\000\000\000\000\000"
  "\157\162\147\057\002\000\000\000\057\000\000\000\003\000\000\000"
  "\146\151\163\150\056\165\151\000\350\152\000\000\001\000\000\000"
  "\170\332\355\135\337\163\243\066\020\176\357\137\241\362\332\161"
  "\154\310\345\222\273\261\175\163\115\173\327\316\164\072\067\275"
  "\353\063\043\303\332\350\042\044\052\204\235\374\367\025\340\044"
  "\070\306\200\020\076\377\010\231\074\044\106\273\150\077\264\273"
  "\037\273\040\217\077\334\207\024\055\101\304\204\263\211\145\137"
  "\214\054\004\314\343\076\141\213\211\365\357\267\117\203\033\353"
  "\303\364\247\361\317\203\001\372\014\014\004\226\340\243\025\221"
  "\001\132\120\354\003\272\274\160\234\213\021\032\014\324\040\302"
  "\044\210\071\366\140\372\023\102\143\001\377\045\104\100\214\050"
  "\231\115\254\205\274\373\305\172\076\121\052\146\015\263\161\174"
  "\366\035\074\211\074\212\343\170\142\175\226\167\037\375\357\111"
  "\054\103\140\322\102\304\237\130\370\351\177\333\112\045\224\114"
  "\044\170\004\102\076\040\206\103\230\130\224\257\100\130\123\173"
  "\074\174\074\120\076\056\211\242\164\234\163\165\125\067\162\211"
  "\151\002\326\364\262\156\134\054\041\162\011\363\004\144\363\255"
  "\237\102\204\027\120\024\170\061\223\361\060\207\103\027\031\247"
  "\032\231\321\205\075\332\374\151\212\225\075\152\010\225\255\013"
  "\125\213\071\275\004\317\326\001\357\317\120\111\347\270\221\364"
  "\317\135\213\151\111\142\062\243\312\242\157\042\201\272\031\171"
  "\230\271\163\356\045\261\065\375\204\151\134\073\236\170\234\271"
  "\351\237\326\064\000\032\015\146\202\257\142\020\046\166\070\007"
  "\266\143\105\230\317\127\003\217\362\227\142\325\166\374\106\060"
  "\345\213\334\220\071\211\003\067\022\060\007\241\242\017\304\256"
  "\237\037\354\146\262\063\056\174\020\356\212\370\062\330\362\270"
  "\355\341\222\110\005\033\222\002\263\230\142\211\025\210\023\353"
  "\001\322\263\251\151\242\057\317\323\254\325\364\020\201\033\220"
  "\164\251\346\006\155\011\170\001\241\076\312\002\047\303\164\220"
  "\375\253\056\335\214\337\257\155\057\103\356\127\165\064\203\055"
  "\127\072\110\207\073\117\343\065\127\102\033\200\313\144\270\040"
  "\312\047\261\124\341\335\232\252\070\057\211\207\151\023\301\070"
  "\302\236\312\066\052\054\227\216\056\107\010\173\351\211\134\054"
  "\000\027\014\057\005\053\221\222\263\227\220\025\344\235\015\005"
  "\055\320\153\213\340\263\171\233\237\355\266\042\067\041\015\034"
  "\356\054\377\340\245\144\111\006\300\063\240\245\253\331\375\103"
  "\051\332\065\261\326\110\324\240\321\106\324\207\071\116\250\324"
  "\027\026\340\001\131\246\341\344\121\103\345\305\050\015\164\131"
  "\264\235\346\031\103\107\060\211\301\115\230\212\073\224\260\132"
  "\310\212\221\162\123\051\366\356\224\163\324\237\016\356\043\314"
  "\374\026\006\316\011\245\055\304\042\036\223\334\327\107\125\146"
  "\225\316\177\074\054\131\365\155\074\301\347\014\072\361\204\333"
  "\355\344\165\146\256\020\340\370\150\374\310\351\375\250\304\217"
  "\354\056\374\250\014\200\162\343\133\031\336\302\350\155\016\357"
  "\335\271\051\061\262\246\300\374\306\122\165\341\246\004\242\055"
  "\170\266\103\114\005\267\112\111\325\325\101\251\201\036\213\065"
  "\346\145\225\334\314\276\061\146\060\105\140\337\132\077\046\304"
  "\152\273\243\026\132\225\210\275\255\224\052\005\255\034\270\277"
  "\362\264\225\102\227\145\060\373\322\052\023\064\000\320\024\104"
  "\275\144\233\227\221\250\256\302\173\114\311\242\232\156\254\005"
  "\261\224\202\050\126\000\161\371\200\342\220\265\362\025\220\105"
  "\040\055\224\325\062\122\127\243\176\136\235\052\221\035\126\353"
  "\337\225\202\252\323\220\121\052\062\110\107\255\251\135\105\132"
  "\332\111\361\164\127\376\123\310\010\166\204\214\303\257\372\235"
  "\326\064\364\345\135\126\031\133\326\205\165\273\375\172\272\276"
  "\374\065\342\125\276\120\357\017\306\076\141\350\027\106\276\121"
  "\343\037\225\076\322\146\145\155\244\327\353\123\133\125\332\151"
  "\327\054\375\066\003\271\101\120\262\255\052\341\016\300\356\012"
  "\360\152\162\347\064\126\121\013\130\155\334\113\317\355\256\243"
  "\110\215\236\216\360\353\022\103\315\272\302\337\152\000\342\163"
  "\224\326\267\337\233\234\043\275\013\016\261\270\113\042\163\333"
  "\265\356\250\353\325\205\014\102\316\210\227\336\231\054\100\132"
  "\323\354\012\053\167\026\017\046\152\033\363\275\346\351\246\171"
  "\332\351\054\375\164\224\206\072\111\107\015\323\122\243\364\144"
  "\032\020\176\117\227\107\041\040\144\313\345\110\002\202\251\252"
  "\264\267\260\304\022\064\012\156\207\132\307\246\246\346\313\330"
  "\124\113\243\032\330\376\126\161\023\270\233\101\335\111\270\060"
  "\307\330\070\112\064\300\266\026\127\143\156\165\331\163\053\135"
  "\156\345\361\060\124\013\356\265\320\253\133\356\146\366\042\311"
  "\221\110\030\132\005\300\024\060\304\273\003\377\375\061\063\244"
  "\307\353\324\223\244\236\044\065\043\111\033\053\246\347\111\075"
  "\117\352\171\322\076\171\222\375\243\170\322\321\126\110\333\126"
  "\003\265\060\154\137\040\075\252\056\113\233\116\103\143\234\364"
  "\233\054\007\177\010\102\267\141\173\270\147\211\212\105\363\233"
  "\276\047\335\276\047\355\234\166\117\372\043\043\141\006\160\337"
  "\225\356\273\322\072\105\212\353\263\354\112\137\237\146\127\272"
  "\314\263\373\106\365\061\067\252\337\365\215\352\275\065\252\013"
  "\357\011\105\002\226\004\126\356\372\041\334\123\051\253\236\304"
  "\015\247\221\212\323\254\314\073\175\145\136\067\257\146\236\367"
  "\152\036\173\370\104\050\034\123\001\276\105\231\174\133\311\303"
  "\243\222\213\267\371\353\252\316\345\315\033\373\346\352\372\235"
  "\335\127\337\317\260\372\236\056\342\333\200\363\030\104\361\235"
  "\243\334\223\275\374\300\271\370\362\356\127\136\277\002\115\141"
  "\301\114\375\066\274\107\356\013\364\175\201\176\357\174\311\076"
  "\041\276\164\323\363\045\375\133\103\173\164\056\301\265\365\075"
  "\143\067\367\216\273\264\004\074\344\013\140\300\133\365\162\033"
  "\135\342\132\132\074\027\152\052\161\143\136\334\351\045\357\372"
  "\262\153\162\344\157\134\142\212\162\000\020\051\244\327\367\246"
  "\047\065\044\317\215\236\140\131\137\270\070\042\314\124\167\053"
  "\162\336\234\133\350\361\213\116\031\165\207\254\272\063\146\255"
  "\301\070\032\063\354\016\003\102\034\001\370\257\062\036\174\301"
  "\312\157\221\032\234\307\204\223\210\002\371\325\352\203\300\121"
  "\004\001\373\320\101\240\257\155\234\114\155\343\263\040\176\036"
  "\160\263\030\344\234\013\325\026\174\345\166\303\216\075\116\223"
  "\220\265\125\326\051\073\126\253\114\236\157\112\134\256\043\277"
  "\007\351\026\137\373\113\260\071\230\147\237\247\050\314\245\213"
  "\245\304\136\240\235\022\112\352\202\074\172\122\166\156\044\263"
  "\167\253\056\334\052\006\217\063\377\120\176\125\321\245\171\175"
  "\016\152\237\266\203\176\125\267\021\305\106\313\363\315\305\221"
  "\371\147\027\352\236\167\356\265\246\205\135\174\215\147\111\111"
  "\070\163\323\115\232\213\373\353\332\157\336\231\052\366\311\202"
  "\310\270\203\005\313\222\020\004\361\332\240\170\040\037\035\365"
  "\076\272\323\107\013\145\300\127\343\244\166\227\116\332\373\323"
  "\211\223\322\276\305\335\267\270\367\324\342\166\216\273\305\175"
  "\033\200\267\261\033\257\340\122\305\064\127\362\305\202\352\076"
  "\145\132\121\030\377\047\123\213\070\103\217\275\123\244\256\024"
  "\320\270\055\302\135\267\327\115\324\264\330\131\167\117\105\377"
  "\055\306\047\360\312\045\314\127\200\113\056\164\164\275\046\037"
  "\275\074\375\027\105\333\076\116\337\277\047\332\277\047\172\250"
  "\367\104\117\167\257\154\235\235\242\153\355\255\337\364\172\323"
  "\306\215\203\343\374\073\060\006\171\063\367\351\255\301\315\217"
  "\221\200\070\342\054\126\263\031\330\166\376\245\065\353\035\367"
  "\307\303\215\221\365\362\127\326\264\260\141\177\251\370\213\017"
  "\343\342\267\244\074\235\040\242\330\203\200\123\225\346\206\133"
  "\166\075\033\074\036\026\276\217\352\177\316\066\145\211\000\050"
  "\165\165\141\171\051\141\160\160\154\145\164\057\007\000\000\000"
  "\146\151\163\150\057\000\000\000\001\000\000\000\005\000\000\000"
  "" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { fish_resource_data.data, sizeof (fish_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *fish_get_resource (void);
GResource *fish_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
